==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/global_resources/translations/agendaplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Agenda</name>
    <message>
        <location filename="../../plugins/agendaplugin/constants.h" line="190"/>
        <source>Print current selection</source>
        <translation>Imprimer la sélection</translation>
    </message>
</context>
<context>
    <name>Agenda::AgendaPlugin</name>
    <message>
        <location filename="../../plugins/agendaplugin/agendaplugin.cpp" line="115"/>
        <source>Initializing agenda plugin...</source>
        <translation>Initialisation du plugin agenda...</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/agendaplugin.cpp" line="122"/>
        <source>Creating agenda base...</source>
        <translation>Création de la base de données agenda...</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/agendaplugin.cpp" line="122"/>
        <source>Please wait</source>
        <translation>Veuillez patienter</translation>
    </message>
</context>
<context>
    <name>Agenda::AvailabilityCreatorDialog</name>
    <message>
        <location filename="../../plugins/agendaplugin/availabilitycreatordialog.ui" line="14"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/availabilitycreatordialog.ui" line="32"/>
        <source>Day availability creator</source>
        <translation>Création de disponibilités</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/availabilitycreatordialog.ui" line="49"/>
        <source>Day of week</source>
        <translation>Jour de la semaine</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/availabilitycreatordialog.ui" line="59"/>
        <source>Start time</source>
        <translation>Heure de départ</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/availabilitycreatordialog.ui" line="69"/>
        <source>End time</source>
        <translation>Heure de fin</translation>
    </message>
</context>
<context>
    <name>Agenda::CalendarItemModel</name>
    <message>
        <location filename="../../plugins/agendaplugin/calendaritemmodel.cpp" line="321"/>
        <source>Empty</source>
        <translation>Vide</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::AgendaMode</name>
    <message>
        <location filename="../../plugins/agendaplugin/agendamode.cpp" line="61"/>
        <location filename="../../plugins/agendaplugin/agendamode.cpp" line="79"/>
        <source>Agenda</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::AgendaPreferencesPage</name>
    <message>
        <location filename="../../plugins/agendaplugin/agendapreferencespage.cpp" line="75"/>
        <source>Agenda preferences</source>
        <translation>Préférences de l&apos;agenda</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::AgendaPreferencesWidget</name>
    <message>
        <location filename="../../plugins/agendaplugin/agendapreferencespage.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::CalendarItemEditorPatientMapper</name>
    <message>
        <location filename="../../plugins/agendaplugin/calendaritemeditorpatientmapper.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/calendaritemeditorpatientmapper.ui" line="26"/>
        <source>Patients</source>
        <translation>Patients</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/calendaritemeditorpatientmapper.ui" line="46"/>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::CalendarItemEditorPatientMapperWidget</name>
    <message>
        <location filename="../../plugins/agendaplugin/calendaritemeditorpatientmapper.cpp" line="157"/>
        <location filename="../../plugins/agendaplugin/calendaritemeditorpatientmapper.cpp" line="158"/>
        <location filename="../../plugins/agendaplugin/calendaritemeditorpatientmapper.cpp" line="288"/>
        <location filename="../../plugins/agendaplugin/calendaritemeditorpatientmapper.cpp" line="289"/>
        <source>Add current patient</source>
        <translation>Ajouter le patient en cours</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::NextAvailabiliyStepViewer</name>
    <message>
        <location filename="../../plugins/agendaplugin/nextavailabiliystepviewer.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarDelegatesMapperWidget</name>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendardelegatesmapper.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendardelegatesmapper.ui" line="23"/>
        <source>Delegates</source>
        <translation>Délégués</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendardelegatesmapper.ui" line="43"/>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarPageForUserViewer</name>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarpageforuserviewer.cpp" line="139"/>
        <source>User agendas</source>
        <translation>Agenda(s) de l&apos;utilisateur</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarViewer</name>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.ui" line="27"/>
        <source>You are</source>
        <translation>Vous êtes</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.ui" line="52"/>
        <source>Your agendas</source>
        <translation>Vos agendas</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.ui" line="68"/>
        <source>Availabilities</source>
        <translation>Disponibilités</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.ui" line="97"/>
        <source>Search parameters</source>
        <translation>Paramètres de recherche</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.ui" line="172"/>
        <source>Duration</source>
        <translation>Duréé</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.ui" line="214"/>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.cpp" line="366"/>
        <location filename="../../plugins/agendaplugin/usercalendarviewer.cpp" line="432"/>
        <source>Set back to default: </source>
        <extracomment>default agenda duration time (in minutes)
----------
default agenda duration time (in minutes)</extracomment>
        <translation>Remettre la valeur par défaut: </translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarWizardCreatorPage</name>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.cpp" line="62"/>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.cpp" line="67"/>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.cpp" line="72"/>
        <source>User&apos;s agendas</source>
        <translation>Agendas de l&apos;utilisateur</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarWizardCreatorWidget</name>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="20"/>
        <source>Quick params</source>
        <translation>Paramètres rapides</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="32"/>
        <source>Label</source>
        <translation>Libellé</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="61"/>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="84"/>
        <source>Default appointement duration</source>
        <translation>Durée par défaut des rendez-vous</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="104"/>
        <source>minutes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="111"/>
        <source>Default location</source>
        <translation>Localisation par défaut</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="137"/>
        <source>Do you want to create an agenda for this user ?</source>
        <translation>Voulez-vous créer un agenda pour cet utilisateur ?</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.ui" line="143"/>
        <source>Create an agenda</source>
        <translation>Créer un agenda</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarWizardPage</name>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.cpp" line="124"/>
        <source>Please specify a label for this agenda.</source>
        <translation>Veuillez spécifier un libellé pour l&apos;agenda.</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.cpp" line="127"/>
        <source>The default duration can not be null.</source>
        <translation>La durée par défaut ne peut pas être nulle.</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.cpp" line="130"/>
        <source>Error detected</source>
        <translation>Erreur détectée</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.cpp" line="140"/>
        <source>Manage an agenda.</source>
        <translation>Gérer un agenda.</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarwizardcreatorpage.cpp" line="141"/>
        <source>You can quickly define an agenda for this user. This agenda will be the default one.</source>
        <translation>Vous pouvez rapidement définir un agenda pour cet utilisateur. Cet agenda sera l&apos;agenda par défaut.</translation>
    </message>
</context>
<context>
    <name>Agenda::UserCalendarEditorWidget</name>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="20"/>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="67"/>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="103"/>
        <source>Label</source>
        <translation>Libellé</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="48"/>
        <source>Icon</source>
        <translation>Icône</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="90"/>
        <source>Select</source>
        <translation>Sélectionner</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="134"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="149"/>
        <source>Default event duration</source>
        <translation>Durée par défaut des rendez-vous</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="172"/>
        <source>Default location</source>
        <translation>Localisation par défaut</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="156"/>
        <source> minutes</source>
        <translation>minutes</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="182"/>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="195"/>
        <source>Agenda is the default agenda</source>
        <translation>est l&apos;agenda par défault</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="202"/>
        <source>Agenda is private</source>
        <translation>L&apos;agenda est privé</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="210"/>
        <source>Shared</source>
        <translation>Partagé</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="236"/>
        <source>Availabilities</source>
        <translation>Disponibilités</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="261"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="271"/>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.ui" line="278"/>
        <source>Remove</source>
        <translation>Enlever</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.cpp" line="150"/>
        <location filename="../../plugins/agendaplugin/usercalendareditor.cpp" line="162"/>
        <source>Can not delete all availabilities</source>
        <translation>Impossible d&apos;effacer les disponibilités</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.cpp" line="151"/>
        <location filename="../../plugins/agendaplugin/usercalendareditor.cpp" line="163"/>
        <source>Agenda must have at least one availability. You can not delete all its availabilities.</source>
        <translation>L&apos;agenda doit avoir au moins une disponibilité. Vous ne pouvez pas effacer toutes ses disponibilités.</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.cpp" line="155"/>
        <source>Delete full day.</source>
        <translation>Effacer une journée entière.</translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendareditor.cpp" line="156"/>
        <source>You are about to delete all recorded time range for one specific day of the week (%1). Do you really want to delete all time range?</source>
        <translation>Vous allez effacer toutes les tranches horaires pour une journée spécifique de la semaine (%1). Voulez-vous réellement les effacer ?</translation>
    </message>
</context>
<context>
    <name>Agenda::UserCalendarModelFullEditorWidget</name>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarmodelfulleditorwidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/agendaplugin/usercalendarmodelfulleditorwidget.cpp" line="72"/>
        <location filename="../../plugins/agendaplugin/usercalendarmodelfulleditorwidget.cpp" line="127"/>
        <source>Create a new calendar</source>
        <translation>Créer un agenda</translation>
    </message>
</context>
<context>
    <name>AgendaBase</name>
    <message>
        <location filename="../../plugins/agendaplugin/agendabase.cpp" line="410"/>
        <source>Trying to create empty database.
       Location: %1
       FileName: %2
       Driver: %3</source>
        <translation>Essaie de créer une base de données vide.
       Location: %1
       FileName: %2
       Driver: %3</translation>
    </message>
</context>
</TS>

==> freemedforms-project_0.8.0.orig.tar.gz: freemedforms-0.8.0/global_resources/translations/agendaplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Agenda</name>
    <message>
        <source>Print current selection</source>
        <translation>Imprimer la sélection</translation>
    </message>
</context>
<context>
    <name>Agenda::AgendaPlugin</name>
    <message>
        <source>Initializing agenda plugin...</source>
        <translation>Initialisation du plugin agenda...</translation>
    </message>
    <message>
        <source>Creating agenda base...</source>
        <translation>Création de la base de données agenda...</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Veuillez patienter</translation>
    </message>
</context>
<context>
    <name>Agenda::AvailabilityCreatorDialog</name>
    <message>
        <source>Day availability creator</source>
        <translation>Création de disponibilités</translation>
    </message>
    <message>
        <source>Day of week</source>
        <translation>Jour de la semaine</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Heure de départ</translation>
    </message>
    <message>
        <source>End time</source>
        <translation>Heure de fin</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Agenda::CalendarItemModel</name>
    <message>
        <source>Empty</source>
        <translation>Vide</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::AgendaMode</name>
    <message>
        <source>Agenda</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::AgendaPreferencesPage</name>
    <message>
        <source>Agenda preferences</source>
        <translation>Préférences de l&apos;agenda</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::AgendaPreferencesWidget</name>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::CalendarItemEditorPatientMapper</name>
    <message>
        <source>Patients</source>
        <translation>Patients</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::CalendarItemEditorPatientMapperWidget</name>
    <message>
        <source>Add current patient</source>
        <translation>Ajouter le patient en cours</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::NextAvailabiliyStepViewer</name>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarDelegatesMapperWidget</name>
    <message>
        <source>Delegates</source>
        <translation>Délégués</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarPageForUserViewer</name>
    <message>
        <source>User agendas</source>
        <translation>Agenda(s) de l&apos;utilisateur</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarViewer</name>
    <message>
        <source>Availabilities</source>
        <translation>Disponibilités</translation>
    </message>
    <message>
        <source>Search parameters</source>
        <translation>Paramètres de recherche</translation>
    </message>
    <message>
        <source>Set back to default: </source>
        <extracomment>default agenda duration time (in minutes)</extracomment>
        <translation>Remettre la valeur par défaut: </translation>
    </message>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Durée :</translation>
    </message>
    <message>
        <source>Available appointments:</source>
        <translation>Plages horaires disponibles :</translation>
    </message>
    <message>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <source>Refresh Availabilities</source>
        <translation>Rafraîchir les disponibilités</translation>
    </message>
    <message>
        <source>Set back to default: %1 %2</source>
        <extracomment>default agenda duration time, %1 = time, %2 = minutes (fixed)</extracomment>
        <translation>Re-définir les valeur par défaut : %1 %2</translation>
    </message>
    <message>
        <source>Agendas of %1</source>
        <extracomment>e.g. Agendas of John Doe</extracomment>
        <translation>Agendas de %1</translation>
    </message>
    <message>
        <source>Beginning of next week</source>
        <translation>Commencement de la semaine</translation>
    </message>
    <message>
        <source>Beginning of next month</source>
        <translation>Commencement du mois</translation>
    </message>
    <message>
        <source>Switch to patient</source>
        <translation>Passer à ce patient</translation>
    </message>
    <message>
        <source>Edit appointment</source>
        <translation>Éditer le rendez-vous</translation>
    </message>
    <message>
        <source>Print appointment</source>
        <translation>Imprimer le rendez-vous</translation>
    </message>
    <message>
        <source>Delete appointment</source>
        <translation>Supprimer le rendez-vous</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarWizardCreatorPage</name>
    <message>
        <source>User&apos;s agendas</source>
        <translation>Agendas de l&apos;utilisateur</translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarWizardCreatorWidget</name>
    <message>
        <source>Quick params</source>
        <translation>Paramètres rapides</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Libellé</translation>
    </message>
    <message>
        <source>Default location</source>
        <translation>Localisation par défaut</translation>
    </message>
    <message>
        <source>Do you want to create an agenda for this user ?</source>
        <translation>Voulez-vous créer un agenda pour cet utilisateur ?</translation>
    </message>
    <message>
        <source>Create an agenda</source>
        <translation>Créer un agenda</translation>
    </message>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <source>Default appointment duration</source>
        <translation>Durée par défaut des rendez-vous</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Agenda::Internal::UserCalendarWizardPage</name>
    <message>
        <source>Please specify a label for this agenda.</source>
        <translation>Veuillez spécifier un libellé pour l&apos;agenda.</translation>
    </message>
    <message>
        <source>The default duration can not be null.</source>
        <translation>La durée par défaut ne peut pas être nulle.</translation>
    </message>
    <message>
        <source>Error detected</source>
        <translation>Erreur détectée</translation>
    </message>
    <message>
        <source>Manage an agenda.</source>
        <translation>Gérer un agenda.</translation>
    </message>
    <message>
        <source>You can quickly define an agenda for this user. This agenda will be the default one.</source>
        <translation>Vous pouvez rapidement définir un agenda pour cet utilisateur. Cet agenda sera l&apos;agenda par défaut.</translation>
    </message>
</context>
<context>
    <name>Agenda::UserCalendarEditorWidget</name>
    <message>
        <source>Label</source>
        <translation>Libellé</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Icône</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Default event duration</source>
        <translation>Durée par défaut des rendez-vous</translation>
    </message>
    <message>
        <source>Default location</source>
        <translation>Localisation par défaut</translation>
    </message>
    <message>
        <source> minutes</source>
        <translation>minutes</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Agenda is the default agenda</source>
        <translation>est l&apos;agenda par défault</translation>
    </message>
    <message>
        <source>Agenda is private</source>
        <translation>L&apos;agenda est privé</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Partagé</translation>
    </message>
    <message>
        <source>Availabilities</source>
        <translation>Disponibilités</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Enlever</translation>
    </message>
    <message>
        <source>Can not delete all availabilities</source>
        <translation>Impossible d&apos;effacer les disponibilités</translation>
    </message>
    <message>
        <source>Agenda must have at least one availability. You can not delete all its availabilities.</source>
        <translation>L&apos;agenda doit avoir au moins une disponibilité. Vous ne pouvez pas effacer toutes ses disponibilités.</translation>
    </message>
    <message>
        <source>Delete full day.</source>
        <translation>Effacer une journée entière.</translation>
    </message>
    <message>
        <source>You are about to delete all recorded time range for one specific day of the week (%1). Do you really want to delete all time range?</source>
        <translation>Vous allez effacer toutes les tranches horaires pour une journée spécifique de la semaine (%1). Voulez-vous réellement les effacer ?</translation>
    </message>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <source>Description</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Agenda::UserCalendarModelFullEditorWidget</name>
    <message>
        <source>Create a new calendar</source>
        <translation>Créer un agenda</translation>
    </message>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AgendaBase</name>
    <message>
        <source>Trying to create empty database.
       Location: %1
       FileName: %2
       Driver: %3</source>
        <translation>Essaie de créer une base de données vide.
       Location: %1
       FileName: %2
       Driver: %3</translation>
    </message>
</context>
</TS>
